@@ -26,11 +26,6 @@ def main(workflows):
 if __name__ == "__main__":
   parser = argparse.ArgumentParser(description="Run Laboro workflow",
                                    prog="laboro")
-  parser.add_argument("-m", "--modules",
-                      metavar="modules",
-                      nargs="+",
-                      default=list(),
-                      help="install the specified modules")
   parser.add_argument("-r", "--run",
                       metavar="workflow",
                       nargs="+",
