@@ -37,8 +37,8 @@ class Manager:
     schema = os.path.join(os.path.dirname(__file__),
                           "schema",
                           "main.yml")
-    self._main_config = Validator().validate_instance(schema=schema,
-                                                      instance=filename)
+    self._main_config = Validator().validate_from_files(schema=schema,
+                                                        instance=filename)
 
   @workflow_config.setter
   def workflow_config(self, filename):
@@ -49,8 +49,8 @@ class Manager:
     schema = os.path.join(os.path.dirname(__file__),
                           "schema",
                           "workflow.yml")
-    self._workflow_config = Validator().validate_instance(schema=schema,
-                                                          instance=filename)
+    self._workflow_config = Validator().validate_from_files(schema=schema,
+                                                            instance=filename)
 
   def __init__(self, main_config):
     self.main_config = main_config
@@ -82,8 +82,10 @@ class Manager:
       try:
         return JSONPath(param).parse(config)[0]
       except IndexError as err:
-        logging.critical(f"UnknownParameter: [{level}]: {param}")
-        raise LaboroError(f"UnknownParameter: [{level}]: {param}") from err
+        msg = f"UnknownParameterError: [{level}]: {param}"
+        logging.critical(msg)
+        raise LaboroError(msg) from err
     except KeyError as err:
-      logging.critical(f"BadConfLevel: Bad configuration level: {level}")
-      raise LaboroError(f"BadConfLevel: Bad configuration level: {level}") from err
+      msg = f"BadConfLevelError: Bad configuration level: {level}"
+      logging.critical(msg)
+      raise LaboroError(msg) from err
