@@ -12,24 +12,26 @@ from laboro.error.handler import Handler as ErrorHandler
 class Context:
   """The ``laboro.context.Context`` object manages all low level tasks for ``laboro.workflow.Workflow`` instances. It is instantiated once by the main **Laboro** process in a **Laboro** execution ans is passed from **Workflow** instances to **Workflow** instances.
 
-  It loads the main **Laboro** configuration file ``/etc/laboro/laboro.yml`` and initiate all needed **Laboro** submodules.
+  It loads the main **Laboro** configuration file and initiate all needed **Laboro** submodules.
 
   Arguments:
     logger: A ``laboro.logger.manager.Manager`` instance.
 
+    main_config_file: Optional, a string specifying the main **Laboro** configuration file path. Defaults to ``/etc/laboro/laboro.yml``.
+
   Raises:
     ``laboro.error.LaboroError``: If the main **Laboro** configuration file is not found or invalid.
 
   Returns:
     ``laboro.context.Context``
   """
-  def __init__(self, logger):
+  def __init__(self, logger, main_config_file="/etc/laboro/laboro.yml"):
     self.delete_workspace_on_exit = True
     self.logger = logger
     self.store = Store()
     self.history = None
     self.modulemgr = ModuleMgr()
-    self.configmgr = ConfigMgr("/etc/laboro/laboro.yml")
+    self.configmgr = ConfigMgr(main_config_file)
     self.workspacedir = self.configmgr.get_parameter("main",
                                                      "$.laboro.workspacedir")
     self.histdir = self.configmgr.get_parameter("main",
@@ -141,7 +143,7 @@ class Context:
     self.modulemgr.register_class_from_module(cls, module)
 
   def _register_instance_secrets(self, instance, args):
-    if args is not None:
+    if "args" in instance.specification and args is not None:
       class_args = instance.specification["args"]
       secret_keys = [arg["name"] for arg in class_args if arg["secret"]]
       secrets = [args[key] for key in args.keys() if key in secret_keys]
@@ -185,9 +187,11 @@ class Context:
     """
     if args is not None:
       try:
-        method_args = [meth for meth in instance.specification["methods"] if meth["name"] == method][0]["args"]
-        secret_keys = [arg["name"] for arg in method_args if arg["secret"]]
-        secrets = [args[key] for key in args.keys() if key in secret_keys]
-        list(map(logging.getLogger().vault.add, secrets))
+        method_spec = [meth for meth in instance.specification["methods"] if meth["name"] == method][0]
+        if "args" in method_spec:
+          method_args = method_spec["args"]
+          secret_keys = [arg["name"] for arg in method_args if arg["secret"]]
+          secrets = [args[key] for key in args.keys() if key in secret_keys]
+          list(map(logging.getLogger().vault.add, secrets))
       except IndexError as err:
         raise LaboroError(f"UnknownMethodError: Unknown method {instance.__class__.__name__}.{method}") from err
