@@ -1,5 +1,5 @@
 class LaboroError(Exception):
-  """Laboro specific error class.
+  """**Laboro** specific and versatile error class.
 
   Arguments:
     message: A string defining the message to be displayed when error occurs.
