@@ -39,15 +39,6 @@ class History:
         cursor.execute("CREATE TABLE executions (workflow, session TEXT, start REAL, end REAL, duration TEXT, params TEXT, exit_code INTEGER)")
         conn.commit()
 
-  def _get_start(self, session):
-    with sqlite3.connect(self.hist_filename) as conn:
-      cursor = conn.cursor()
-      cursor.execute("select start from executions where session=?", [session])
-      try:
-        return cursor.fetchone()[0]
-      except IndexError:
-        return 0
-
   def _end_exec(self, exit_code):
     logging.info(f"[+] Registering end of session: [{self.session}]: {exit_code}")
     end = time.time()
@@ -145,6 +136,6 @@ class History:
                          "Exit"]
     with sqlite3.connect(self.hist_filename) as conn:
       cursor = conn.cursor()
-      cursor.execute("select * from executions where workflow=? order by start desc limit=?", [workflow, num_exec])
+      cursor.execute("select * from executions where workflow=? order by start desc limit ?", [workflow, num_exec])
       table.add_rows(cursor.fetchall())
       return table.get_string()
