@@ -7,7 +7,9 @@ class Parser:
   @staticmethod
   def eval(expression):
     try:
-      return Interpreter().eval(expression)
+      return Interpreter().eval(expression,
+                                show_errors=False,
+                                raise_errors=True)
     except SyntaxError as err:
       logging.critical(f"Invalid syntax for expression: {expression}")
       raise err
