@@ -1,5 +1,4 @@
 import os
-import logging
 from laboro.error import LaboroError
 from laboro.validator import Validator
 
@@ -47,21 +46,15 @@ class Module:
     """The ``@laboro.module.Module.laboro_method`` decorator provides the way to validate the module methods arguments against the module method specification. All module derived from the `laboro.module.Module`` **must** decorate all their **public methods**.
     """
     def wrapper(self, *args, **kwargs):
-      if len(args) > 1:
-        logging.error("Using method with args instead of kwargs !")
-        logging.warning("No argument checking will be done.")
-        self.context.put(func.__name__, func(*args[1:]))
-        return self.context.get(func.__name__)
-      else:
-        try:
-          method = func.__name__
-          methods = self.specification["methods"]
-          method = [meth for meth in methods if meth["name"] == method][0]
-          Validator().validate_method_args(method, kwargs)
-        except IndexError as err:
-          raise LaboroError(f"UnknownMethodError: Unknown method: {method}") from err
-        self.context.put(func.__name__, func(self, **kwargs))
-        return self.context.get(func.__name__)
+      try:
+        method = func.__name__
+        methods = self.specification["methods"]
+        method = [meth for meth in methods if meth["name"] == method][0]
+        Validator().validate_method_args(method, kwargs)
+      except IndexError as err:
+        raise LaboroError(f"UnknownMethodError: Unknown method: {method}") from err
+      self.context.put(func.__name__, func(self, **kwargs))
+      return self.context.get(func.__name__)
     return wrapper
 
   def _validate_spec(self):
@@ -72,8 +65,8 @@ class Module:
     spec_file = os.path.join(os.path.dirname(self.filepath),
                              "schema",
                              "specification.yml")
-    return Validator().validate_instance(schema=base_spec,
-                                         instance=spec_file)
+    return Validator().validate_from_files(schema=base_spec,
+                                           instance=spec_file)
 
   def _validate_args(self):
     """Validate arguments against a specification.
