@@ -42,11 +42,11 @@ class Workflow:
 
   def _is_runnable(self, obj):
     if "when" in obj.keys():
-      return Processor().process(self.ctx, obj["when"])
+      return Processor().process(self.ctx, str(obj["when"]))
     return True
 
   def _get_iterable(self, obj):
-    return Processor().process(self.ctx, obj["loop"])
+    return Processor().process(self.ctx, str(obj["loop"]))
 
   def _interpolate(self, obj):
     if "args" in obj:
@@ -126,3 +126,4 @@ class Workflow:
       else:
         self.ctx.store.step_item = None
         self._do_step(step)
+    logging.getLogger().log_line()
